@@ -3,9 +3,9 @@ from django import forms
 from ..mixins import TapeformMixin
 
 
-class BootstrapTapeformMixin(TapeformMixin):
+class Bootstrap4TapeformMixin(TapeformMixin):
     """
-    Tapeform Mixin to render Bootstrap4 compatible forms.
+    Tapeform Mixin to render Bootstrap v4 compatible forms.
     (using the template tags provided by `tapeforms`).
     """
 
@@ -13,9 +13,9 @@ class BootstrapTapeformMixin(TapeformMixin):
     layout_template = 'tapeforms/layouts/bootstrap.html'
     #: Use a special field template for Bootstrap compatible forms.
     field_template = 'tapeforms/fields/bootstrap.html'
-    #: Bootstrap requires that the field has a css class "form-group" applied.
+    #: All form field containers need a CSS class "form-group".
     field_container_css_class = 'form-group'
-    #: All widgets need a css class "form-control" (except checkables and file inputs).
+    #: Almost all widgets need a CSS class "form-control".
     widget_css_class = 'form-control'
     #: Use a special class to invalid field's widget.
     widget_invalid_css_class = 'is-invalid'
@@ -30,23 +30,22 @@ class BootstrapTapeformMixin(TapeformMixin):
 
     def get_field_container_css_class(self, bound_field):
         """
-        Returns 'form-check' if widget is CheckboxInput. For all other fields,
-        return the default value from the form property ("form-group").
+        Returns "form-check" if widget is CheckboxInput in addition of the
+        default value from the form property ("form-group") - which is returned
+        for all other fields.
         """
-        # If we render CheckboxInputs, Bootstrap requires a different
-        # container class for checkboxes.
-        if isinstance(bound_field.field.widget, forms.CheckboxInput):
-            return 'form-check'
+        class_name = super().get_field_container_css_class(bound_field)
 
-        return super().get_field_container_css_class(bound_field)
+        if isinstance(bound_field.field.widget, forms.CheckboxInput):
+            class_name += ' form-check'
+
+        return class_name
 
     def get_field_label_css_class(self, bound_field):
         """
-        Returns 'form-check-label' if widget is CheckboxInput. For all other fields,
-        no css class is added.
+        Returns "form-check-label" if widget is CheckboxInput. For all other fields,
+        no CSS class is added.
         """
-        # If we render CheckboxInputs, Bootstrap requires a different
-        # field label css class for checkboxes.
         if isinstance(bound_field.field.widget, forms.CheckboxInput):
             return 'form-check-label'
 
@@ -54,12 +53,10 @@ class BootstrapTapeformMixin(TapeformMixin):
 
     def get_widget_css_class(self, field_name, field):
         """
-        Returns 'form-check-input' if input widget is checkable, or
-        'form-control-file' if widget is FileInput. For all other fields
-        return the default value from the form property ("form-control").
+        Returns "form-check-input" if input widget is checkable, or
+        "form-control-file" if widget is FileInput. For all other fields,
+        returns the default value from the form property ("form-control").
         """
-        # If we render checkable input widget, Bootstrap requires a different
-        # widget css class for checkboxes.
         if field.widget.__class__ in [
             forms.RadioSelect,
             forms.CheckboxSelectMultiple,
@@ -67,8 +64,43 @@ class BootstrapTapeformMixin(TapeformMixin):
         ]:
             return 'form-check-input'
 
-        # Idem for fileinput.
         if isinstance(field.widget, forms.FileInput):
             return 'form-control-file'
 
         return super().get_widget_css_class(field_name, field)
+
+
+class Bootstrap5TapeformMixin(Bootstrap4TapeformMixin):
+    """
+    Tapeform Mixin to render Bootstrap v5 compatible forms.
+    (using the template tags provided by `tapeforms`).
+    """
+
+    #: Apply the CSS class "mb-3" to add spacing between the form fields.
+    field_container_css_class = 'mb-3'
+    #: Almost all labels need a CSS class "form-label".
+    field_label_css_class = 'form-label'
+
+    def get_widget_css_class(self, field_name, field):
+        """
+        Returns "form-check-input" if input widget is checkable, or
+        "form-select" if widget is Select or a subclass. For all other fields,
+        returns the default value from the form property ("form-control").
+        """
+        if field.widget.__class__ in [
+            forms.RadioSelect,
+            forms.CheckboxSelectMultiple,
+            forms.CheckboxInput,
+        ]:
+            return 'form-check-input'
+
+        if isinstance(field.widget, forms.Select):
+            return 'form-select'
+
+        return super(Bootstrap4TapeformMixin, self).get_widget_css_class(field_name, field)
+
+
+#: This alias is for backward compatibility only. It could be deprecated and
+#: removed at some time, you should use :py:class:`Bootstrap4TapeformMixin`
+#: or :py:class:`Bootstrap5TapeformMixin` instead.
+BootstrapTapeformMixin = Bootstrap4TapeformMixin
